package com.anabas.testsharedlet;

import javax.swing.*;
import com.anabas.sharedlet.*;
import com.anabas.util.misc.LogManager;

/**
 * A basic view that just display a user settable label.  Extended by the
 * appliation view and presentation view.
 *
 * @author John Yin
 * @version 1.0
 */


class TestSharedletViewBase extends JPanel implements SharedletView {
  /**
   * The label value.
   */
  private String m_name;

  /**
   * The renderer which will only render to java.
   */
  private JavaViewRenderer m_renderer;

  /**
   * The JLabel component that stores the label name.
   */
  private JLabel m_label;

  /**
   * @param label The value of the label.
   */
  public TestSharedletViewBase(String label) {
    m_name = label;
    m_label = new JLabel(label);
    m_label.setBackground(java.awt.Color.white);
    m_label.setOpaque(true);
    this.add(m_label);

    m_renderer = new JavaViewRenderer(this,this);
  }

  public void activate() {
    LogManager.log("View",getID() + " view activated");
  }

  public void deactivate() {
    LogManager.log("View",getID() + " view deactivated");
  }

  public String getID() {
    return m_name;
  }

  /**
   * Change the label value and display it.
   */
  public void displayMessage(String msg) {
    m_label.setText(msg);
  }

  /**
   * Only supports a java rendering (application/java)
   *
   * @return The Java renderer
   */
  public SharedletViewRenderer getRenderer(String mime) {
    if (mime.equals("application/java")) return m_renderer;
    return null;
  }
}