package com.anabas.testsharedlet;


import com.anabas.concepts.*;
import com.anabas.sharedlet.*;
import com.anabas.util.misc.LogManager;
import com.anabas.gxo.*;
import com.anabas.naming.*;

import java.net.URL;
import java.awt.*;
import java.awt.event.*;
import java.util.Enumeration;
import java.util.Vector;
import javax.swing.*;
import com.borland.jbcl.layout.*;

/**
 * Title:
 * Description:
 * Copyright:    Copyright (c) 2000
 * Company:
 * @author
 * @version 1.0
 */

public class TokenTestView extends JPanel implements SharedletView,
                                                     ActionListener,
                                                     SessionListener,
                                                     TokenListener {

  private SharedletViewRenderer m_renderer;

  private TokenService m_tokenService;
  JButton m_releaseTokenButton = new JButton();
  JButton m_requestTokenButton = new JButton();
  VerticalFlowLayout verticalFlowLayout1 = new VerticalFlowLayout();
  JLabel m_ownerLabel = new JLabel();
  JButton m_createTokenButton = new JButton();
  JComboBox m_ownedTokens = new JComboBox();
  JTextField m_tokenName = new JTextField();
  JLabel m_tokenNameLabel = new JLabel();
  JLabel m_ownerLabel1 = new JLabel();
  JTextArea m_feedback = new JTextArea();
  JPanel jPanel1 = new JPanel();
  JButton m_giveButton = new JButton();
  FlowLayout flowLayout1 = new FlowLayout();
  JComboBox m_userList = new JComboBox();


  public TokenTestView() {
    try {
      jbInit();
    } catch (Exception e) {
    }
    // Grab the handle to the communication service and get the handle to the
    // event bus stream for this sharedlet.
    try {
      Context ctx = ContextManager.getInitialContext();
      m_tokenService = (TokenService)ctx.lookup("services/TokenService");
      m_tokenService.addTokenListener(this);

      SessionManager sm = (SessionManager)ctx.lookup("services/SessionManager");
      sm.addSessionListener(this);
      Vector v= sm.getParticipants();
      Enumeration enum = v.elements();
      while(enum.hasMoreElements()) {
        User u = (User)enum.nextElement();
        m_userList.addItem(u.getUserID().toString());
      }
    } catch (Exception e) {
      LogManager.err("TokenTestView","Unable to get token service",e);
    }

    m_renderer = new JavaViewRenderer(this,this);

  }

  public void userJoined(SessionEvent e) {
    User u = (User)e.getSource();
    m_userList.addItem(u.getUserID().toString());
  }

  public void userLeft(SessionEvent e) {
    User u = (User)e.getSource();
    m_userList.removeItem(u.getUserID().toString());
  }

  /**
   * Do nothing.
   */
  public void activate() {
    LogManager.log("View",getID() + " view activated");
  }

  /**
   * Do nothing.
   */
  public void deactivate() {
    LogManager.log("View",getID() + " view deactivated");
  }

  /**
   * Should be triggered by a user clicking on the "Open" button and choosing
   * a file.
   */
  public void loadDocument(java.net.URL documentURL) {
    LogManager.log("View",getID() + " load document: " + documentURL);
  }

  /**
   * @return The unique name of the control view.
   */
  public String getID() {
    return "Token Test";
  }

  /**
   * @return The Java renderer
   */
  public SharedletViewRenderer getRenderer(String MIMEType) {
    if (MIMEType.equals("application/java")) {
      return m_renderer;
    }
    return null;
  }

  public void actionPerformed(ActionEvent e) {
    String cmd = e.getActionCommand();

    if (m_tokenName.getText().length() <= 0) {
      m_feedback.setText("Please enter a token name");
      return;
    }

    if (cmd.equals("create")) {
      try {
        m_tokenService.createToken(m_tokenName.getText());
      } catch (Exception ex) {
        m_feedback.setText("Permission Denied");
      }
    } else if (cmd.equals("request")) {
      m_tokenService.requestToken(m_tokenName.getText());
    } else if (cmd.equals("release")) {
      m_tokenService.releaseToken(m_tokenName.getText());
    } else if (cmd.equals("give")) {
      try {
        if (m_tokenName.getText().length() <= 0) {
          m_feedback.setText("No token name");
        } else if (m_userList.getSelectedItem() == null) {
          m_feedback.setText("Please select user");
        } else {
          m_tokenService.giveToken(m_tokenName.getText(),(String)m_userList.getSelectedItem());
        }
      } catch (Exception ex) {
        m_feedback.setText("Permission Denied");
      }
    }
  }

  public void tokenGained(Token t) {
    addToken(t);
  }

  public void tokenLost(Token t) {
    removeToken(t);
  }

  public void tokenRequestDenied(String token) {
  }

  private void addToken(Token t) {
    for(int i=0;i < m_ownedTokens.getItemCount();i++) {
      String token = (String)m_ownedTokens.getItemAt(i);
      if (token.startsWith("{"+t.getName()+":")) {
        m_ownedTokens.removeItemAt(i);
        m_ownedTokens.addItem(t.toString());
        m_feedback.setText("Replacing old Token: "+t);
        return;
      }
    }
    m_ownedTokens.addItem(t.toString());
    m_feedback.setText("Added New Token: "+t);
  }

  private void removeToken(Token t) {
    for(int i=0;i < m_ownedTokens.getItemCount();i++) {
      String token = (String)m_ownedTokens.getItemAt(i);
      if (token.startsWith("{"+t.getName()+":")) {
        m_ownedTokens.removeItemAt(i);
        break;
      }
    }
    m_feedback.setText("Released Token: " +t);
  }

  private void jbInit() throws Exception {
    m_releaseTokenButton.setActionCommand("release");
    m_releaseTokenButton.setText("Release Token");
    m_requestTokenButton.setActionCommand("request");
    m_requestTokenButton.setText("Request Token");
    this.setLayout(verticalFlowLayout1);
    m_ownerLabel.setBackground(Color.gray);
    m_ownerLabel.setFont(new java.awt.Font("Dialog", 1, 14));
    m_ownerLabel.setForeground(Color.white);
    m_ownerLabel.setOpaque(true);
    m_ownerLabel.setHorizontalAlignment(SwingConstants.CENTER);
    m_ownerLabel.setHorizontalTextPosition(SwingConstants.CENTER);
    m_ownerLabel.setText("Currently Owned Tokens");
    m_createTokenButton.setToolTipText("");
    m_createTokenButton.setActionCommand("create");
    m_createTokenButton.setText("Create Token");
    m_tokenNameLabel.setText("Token Name");
    m_tokenNameLabel.setHorizontalTextPosition(SwingConstants.CENTER);
    m_tokenNameLabel.setHorizontalAlignment(SwingConstants.CENTER);
    m_tokenNameLabel.setOpaque(true);
    m_tokenNameLabel.setForeground(Color.white);
    m_tokenNameLabel.setFont(new java.awt.Font("Dialog", 1, 14));
    m_tokenNameLabel.setBackground(Color.gray);
    m_ownerLabel1.setText("Feedback");
    m_ownerLabel1.setHorizontalTextPosition(SwingConstants.CENTER);
    m_ownerLabel1.setHorizontalAlignment(SwingConstants.CENTER);
    m_ownerLabel1.setOpaque(true);
    m_ownerLabel1.setForeground(Color.white);
    m_ownerLabel1.setFont(new java.awt.Font("Dialog", 1, 14));
    m_ownerLabel1.setBackground(Color.gray);
    m_feedback.setText("Ok");
    m_giveButton.setActionCommand("give");
    m_giveButton.setText("Give");
    flowLayout1.setAlignment(FlowLayout.LEFT);
    jPanel1.setLayout(flowLayout1);
    m_userList.setMinimumSize(new Dimension(60, 21));
    m_userList.setPreferredSize(new Dimension(80, 21));
    this.add(m_tokenNameLabel, null);
    this.add(m_tokenName, null);
    this.add(m_requestTokenButton, null);
    this.add(m_releaseTokenButton, null);
    this.add(m_createTokenButton, null);
    this.add(jPanel1, null);
    jPanel1.add(m_giveButton, null);
    jPanel1.add(m_userList, null);
    this.add(m_ownerLabel, null);
    this.add(m_ownedTokens, null);
    this.add(m_ownerLabel1, null);
    this.add(m_feedback, null);

    m_requestTokenButton.addActionListener(this);
    m_releaseTokenButton.addActionListener(this);
    m_createTokenButton.addActionListener(this);
    m_giveButton.addActionListener(this);
  }
}