package com.anabas.testsharedlet;

import com.anabas.sharedlet.*;
import com.anabas.util.misc.LogManager;
import java.awt.Dimension;
import java.util.Vector;

/**
 * The sharedlet info structure for TestSharedlet.
 *
 * @author John Yin
 * @version 1.0
 */

public class TestSharedletInfo extends SharedletRCUtil implements SharedletInfo {

  /* ======================= Member Variables =========================== */

  /**
   * The unique MIME type for the sharedlet
   */
  public static String g_sharedletMIME = "application/x-sharedlet-test";

  /**
   * This sharedlet supports all document types.  When the loadDocument() method
   * is called, it will just display the action to stdout.
   */
  private static final String[] s_supportedDocTypes = { "*" };

  /**
   * Stores an internal vector of all SharedletViewInfo's
   */
  private Vector m_viewInfos = new Vector();

  /**
   * Stores an internal vector of all SharedletSessionLogicInfo's
   */
  private Vector m_logicInfos = new Vector();


  /* ==================== Methods =================================== */

  /**
   * Constructs 3 view infos, one for each view type
   * (Application,Contro,Presentation).
   *
   * Also setup the list of capabilities, roles, and moderatable elements.
   */
  public TestSharedletInfo() {

    // Setup the list of view infos.
    m_viewInfos.addElement(new ApplicationViewInfo());
    m_viewInfos.addElement(new TestControlViewInfo());
    m_viewInfos.addElement(new PresentationViewInfo());
    //m_viewInfos.addElement(new TokenTestViewInfo());

    // Setup the list of session logic infos.
    m_logicInfos.addElement(new TestSessionLogicInfo());

    /**
     * Setup the list of raw capabilities.
     * start - The sharedlet can generate random numbers
     * take - The sharedlet can take away random number generation capability of another user
     * give - The sharedlet can give away random number generation capability to another user
     * moderate - The sharedlet give permission to another user to remotely enable/disable
     *            random number generation capability.
     */
    setCapabilities("1:start,take,give,moderate");

    /**
     * The "Application Control" element means toggling the start capability
     */
    setModeratable("Application Control","1:start");


    /**
     * A participant starts with no capabilities and can not see the application view.
     */
    setRole("Participant","","Control View,Presentation View,Token Test,Application View","");

    /**
     * A host starts with all possible capabilities and can see all views.
     */
    setRole("Host","1:start,take,give,moderate","Control View,Presentation View,Application View,Token Test","Application Control");

    /**
     * A moderator has everything but the ability to pass on moderation control.
     */
    setRole("Moderator","1:start,take,give","Control View,Presentation View,Application View","Application Control");

  }

  /**
   * @return "Test Sharedlet"
   */
  public String   getDescription() {
    return "Session Document Navigator";
  }

  /**
   * @return application/x-sharedlet-docnav
   */
  public String   getMIMEType()   {
    return g_sharedletMIME;
  }

  /**
   * @return 1.0
   */
  public double   getVersion() {
    return 1.0;
  }

  /**
   * @return The list of view info that was setup in the constructor.
   */
  public Vector getViewInfos() {
    return m_viewInfos;
  }

  /**
   * @return The list of logic info that was setup in teh constructor.
   */
  public Vector getLogicInfos() {
    return m_logicInfos;
  }

  /**
   * @return The list of supported document types which is "*".
   */
  public String[] getSupportedDocumentTypes() {
    return s_supportedDocTypes;
  }
}